@@ -41,7 +41,12 @@
 ;;;### (autoloads nil "hbut" "hbut.el" (0 0 0 0))
 ;;; Generated autoloads from hbut.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hbut" '("ibut:" "ibtype:create" "defib" "map-" "hattr:summarize" "hbut:s" "ebut:")))
+(autoload 'hbut:modify-syntax "hbut" "\
+Modify syntactic character pairs in hbut:syntax-table and help-mode-syntax-table for use with implicit button activations.
+
+\(fn)" nil nil)
+
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hbut" '("ibut:" "ibtype:create" "defib" "map-" "hattr:summarize" "hbut:" "ebut:")))
 
 ;;;***
 
@@ -1241,10 +1246,9 @@ If in an Emacs Lisp mode buffer and no PREFIX-ARG is given, limit search to only
 \(fn PATTERN &optional PREFIX-ARG)" t nil)
 
 (autoload 'hypb:display-file-with-logo "hypb" "\
-Display an optional text FILE in help mode with the Hyperbole banner prepended.
-Without file, the banner is prepended to the current buffer.
+Display a text FILE in help mode with the Hyperbole banner prepended.
 
-\(fn &optional FILE)" nil nil)
+\(fn FILE)" nil nil)
 
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "hypb" '("hypb:")))
 
