@@ -5,8 +5,8 @@
 ;; Author:           Bob Weiner
 ;; Maintainer:       Bob Weiner <rsw@gnu.org>, Mats Lidell <matsl@gnu.org>
 ;; Created:          06-Oct-92 at 11:52:51
-;; Released:         17-Feb-23
-;; Version:          7.1.0
+;; Released:         01-Mar-20
+;; Version:          7.1.1
 ;; Keywords:         comm, convenience, files, frames, hypermedia, languages, mail, matching, mouse, multimedia, outlines, tools, wp
 ;; Package:          hyperbole
 ;; Package-Requires: ((emacs "24.4"))
@@ -657,6 +657,7 @@ If FLAG is nil then text is shown, while if FLAG is t the text is hidden."
   "Standard configuration routine for Hyperbole."
   (interactive)
   (message "Initializing Hyperbole...")
+  ;;
   (run-hooks 'hyperbole-init-hook)
   (hyperb:check-dir-user)
   (or (stringp hyperb:user-email)
@@ -672,7 +673,10 @@ If FLAG is nil then text is shown, while if FLAG is t the text is hidden."
   (unless noninteractive
     (hyperb:maybe-generate-autoloads))
   ;;
-  ;; Conditionally initialize Hyperbole key bindings (when hkey-init is t)
+  ;; Modify syntactic character pairs for use with implicit button activations.
+  (hbut:modify-syntax)
+  ;;
+  ;; Conditionally initialize Hyperbole key bindings (when hkey-init is t).
   (hkey-initialize)
   ;;
   ;; Abbreviate MSWindows mount point paths.
