@@ -15,7 +15,7 @@
 
 (autoload 'kexport:html "kexport" "\
 Export a koutline buffer or file in EXPORT-FROM to html format in OUTPUT-TO.
-By default, this retains newlines within cells as they are.  With optional prefix arg, SOFT-NEWLINES-FLAG, 
+By default, this retains newlines within cells as they are.  With optional prefix arg, SOFT-NEWLINES-FLAG,
 hard newlines are not used.  Also converts Urls and Klinks into Html hyperlinks.
 STILL TODO:
   Make delimited pathnames into file links (but not if within klinks).
@@ -53,7 +53,7 @@ View an existing kotl version-2 file FILE-NAME in a read-only mode.
 ;;;### (autoloads nil "kfill" "kfill.el" (0 0 0 0))
 ;;; Generated autoloads from kfill.el
 
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "kfill" '("kfill:" "set-fill-prefix" "fill-paragraph" "prior-fill-prefix")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "kfill" '("kfill:" "set-fill-prefix" "prior-fill-prefix")))
 
 ;;;***
 
@@ -73,12 +73,12 @@ and a buffer/file into which to insert the imported elements and a third
 optional argument, CHILDREN-P, which when non-nil means insert imported cells
 as the initial set of children of the current cell, if any.
 
-   outline-mode  - imported as an Emacs outline whose entries begin with
-                   asterisks; 
+   `outline-mode'  - imported as an Emacs outline whose entries begin with
+                     asterisks; 
    .kot
-   .kotl         - imported as a structured koutline
+   .kotl           - imported as a structured koutline
 
-   all others    - imported as text.")
+   all others      - imported as text.")
 
 (defvar kimport:suffix-alist '(("\\.otl$" . kimport:star-outline) ("\\.aug$" . kimport:aug-post-outline)) "\
 Alist of (buffer-name-suffix-regexp . importation-function) elements.
@@ -142,6 +142,15 @@ The variable, `paragraph-start,' is used to determine paragraphs.
 
 \(fn IMPORT-FROM OUTPUT-TO &optional CHILDREN-P)" t nil)
 
+(autoload 'kimport:copy-and-set-buffer "kimport" "\
+Copy and untabify SOURCE, set copy buffer as current buffer for this command and return the copy buffer.
+SOURCE may be a buffer name, a buffer or a file name.
+If SOURCE buffer name begins with a space, it is not copied under the
+assumption that it already has been.  If SOURCE is a koutline, it is not
+copied since there is no need to copy it to import it.
+
+\(fn SOURCE)" nil nil)
+
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "kimport" '("kimport:")))
 
 ;;;***
